@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005003';
+our $VERSION   = '0.005004';
 
 has _order =>
   is            => rw,
@@ -18,6 +18,13 @@ has class =>
   isa           => Object,
   weak_ref      => true;
 
+has compiling_class =>
+  init_arg      => undef,
+  is            => rw,
+  isa           => Object,
+  clearer       => true,
+  predicate     => true;
+
 has _class_for_default =>
   is            => rw,
   isa           => Object,
@@ -60,14 +67,12 @@ has [ 'reader', 'writer', 'accessor', 'clearer', 'predicate' ] =>
 has isa =>
   is            => bare,
   isa           => Str|Object,
-  reader        => '_isa', # collision with UNIVERSAL::isa
-  init_arg      => 'isa';
+  reader        => '_%s'; # collision with UNIVERSAL::isa
 
 has does =>
   is            => bare,
   isa           => Str|Object,
-  reader        => '_does', # collision with Mite's does method
-  init_arg      => 'does';
+  reader        => '_%s'; # collision with Mite's does method
 
 has type =>
   is            => 'lazy',
@@ -82,7 +87,7 @@ has coerce =>
 has default =>
   is            => rw,
   isa           => Undef|Str|CodeRef|ScalarRef,
-  predicate     => 'has_default';
+  predicate     => true;
 
 has lazy =>
   is            => rw,
@@ -128,15 +133,17 @@ has alias_is_for =>
 use B ();
 sub _q          { shift; join q[, ], map B::perlstring($_), @_ }
 sub _q_name     { B::perlstring( shift->name ) }
-sub _q_init_arg { B::perlstring( shift->init_arg ) }
+sub _q_init_arg { my $self = shift; B::perlstring( $self->_expand_name( $self->init_arg ) ) }
 
 for my $function ( qw/ carp croak confess / ) {
     no strict 'refs';
     *{"_function_for_$function"} = sub {
         my $self = shift;
-        return $self->class->${\"_function_for_$function"}
-            if ref $self->class;
-        return "require Carp && Carp::$function";
+        return $self->compiling_class->${\"_function_for_$function"}
+            if $self->has_compiling_class;
+        my $shim = eval { $self->class->shim_name };
+        return "$shim\::$function" if $shim;
+        $function eq 'carp' ? 'warn sprintf' : 'die sprintf';
     };
 }
 
@@ -190,6 +197,21 @@ sub BUILD {
     }
 }
 
+sub _expand_name {
+    my ( $self, $name ) = @_;
+
+    return undef unless defined $name;
+    return $name unless $name =~ /\%/;
+
+    my %tokens = (
+        's' => $self->name,
+        '%' => '%',
+    );
+
+    $name =~ s/%(.)/$tokens{$1}/eg;
+    return $name;
+}
+
 sub clone {
     my ( $self, %args ) = ( shift, @_ );
 
@@ -215,23 +237,17 @@ sub is_private {
 
 sub _build_reader {
     my $self = shift;
-    ( $self->is eq ro or $self->is eq rwp )
-        ? $self->name
-        : undef;
+    ( $self->is eq ro or $self->is eq rwp ) ? '%s' : undef;
 }
 
 sub _build_writer {
     my $self = shift;
-    $self->is eq rwp
-        ? sprintf( '_set_%s', $self->name )
-        : undef;
+    ( $self->is eq rwp ) ? '_set_%s' : undef;
 }
 
 sub _build_accessor {
     my $self = shift;
-    $self->is eq rw
-        ? $self->name
-        : undef;
+    ( $self->is eq rw ) ? '%s' : undef;
 }
 
 sub _build_predicate { undef; }
@@ -254,8 +270,7 @@ sub _all_aliases {
     my $self    = shift;
     my $aliases = $self->alias;
     return unless @$aliases;
-    no warnings;
-    return map { sprintf $_, $self->name } @$aliases;
+    map $self->_expand_name($_), @$aliases;
 }
 
 sub _build_type {
@@ -369,7 +384,7 @@ sub _compile_default {
         return defined( $self->default ) ? $self->_q( $self->default ) : 'undef';
     }
     elsif ( $self->has_builder ) {
-        return sprintf '%s->%s', $selfvar, $self->builder;
+        return sprintf '%s->%s', $selfvar, $self->_expand_name( $self->builder );
     }
 
     # should never get here
@@ -378,7 +393,7 @@ sub _compile_default {
 
 sub _compile_trigger {
     my ( $self, $selfvar, @args ) = @_;
-    my $method_name = $self->trigger;
+    my $method_name = $self->_expand_name( $self->trigger );
 
     return sprintf '%s->%s( %s )',
         $selfvar, $method_name, join( q{, }, @args );
@@ -387,74 +402,84 @@ sub _compile_trigger {
 sub compile_init {
     my ( $self, $selfvar, $argvar ) = @_;
 
-    my $init_arg = $self->init_arg;
+    my $init_arg = $self->_expand_name( $self->init_arg );
 
-    my $code = '';
+    my @code;
     if ( defined $init_arg ) {
+
         if ( my @alias = $self->_all_aliases ) {
-            $code .= sprintf 'for my $alias ( %s ) { last if exists %s->{%s}; next if !exists %s->{$alias}; %s->{%s} = %s->{$alias} } ',
+            push @code, sprintf 'for my $alias ( %s ) { last if exists %s->{%s}; next if !exists %s->{$alias}; %s->{%s} = %s->{$alias} } ',
                 $self->_q( @alias ), $argvar, $self->_q_init_arg, $argvar, $argvar, $self->_q_init_arg, $argvar;
         }
-        $code .= sprintf 'if ( exists %s->{%s} ) { ',
-            $argvar, $self->_q_init_arg;
+
+        my $code;
+        my $valuevar = sprintf '%s->{%s}', $argvar, $self->_q_init_arg;
+        my $postamble = '';
+
+        if ( $self->has_default || $self->has_builder and not $self->lazy ) {
+            $code .= sprintf 'do { my $value = exists( %s ) ? %s : %s; ',
+                $valuevar, $valuevar, $self->_compile_default( $selfvar );
+            $valuevar = '$value';
+            $postamble = "}; $postamble";
+        }
+        elsif ( $self->required and not $self->lazy ) {
+            push @code, sprintf '%s "Missing key in constructor: %s" unless exists %s; ',
+                $self->_function_for_croak, $init_arg, $valuevar;
+        }
+        else {
+            my $trigger_code = $self->trigger
+                ? $self->_compile_trigger(
+                    $selfvar,
+                    sprintf( '%s->{%s}', $selfvar, $self->_q_name ),
+                ) . '; '
+                : '';
+
+            $code .= sprintf 'if ( exists %s->{%s} ) { ',
+                $argvar, $self->_q_init_arg;
+            $postamble = "$trigger_code} $postamble";
+        }
+
         if ( my $type = $self->type ) {
             local $Type::Tiny::AvoidCallbacks = 1;
-            my $valuevar = sprintf '%s->{%s}', $argvar, $self->_q_init_arg;
+            
             if ( $self->coerce ) {
-                $code .= sprintf 'my $value = %s; ', $self->_compile_coercion( $valuevar );
-                $valuevar = '$value';
+                $code .= sprintf 'do { my $coerced_value = %s; ', $self->_compile_coercion( $valuevar );
+                $valuevar = '$coerced_value';
+                $postamble = "}; $postamble";
             }
-            $code .= sprintf '%s or %s( "Type check failed in constructor: %%s should be %%s", %s, %s ); ',
+
+            $code .= sprintf '%s or %s "Type check failed in constructor: %%s should be %%s", %s, %s; ',
                 $type->inline_check( $valuevar ),
                 $self->_function_for_croak,
                 $self->_q_init_arg,
                 $self->_q( $type->display_name );
+
             $code .= sprintf '%s->{%s} = %s; ',
                 $selfvar, $self->_q_name, $valuevar;
         }
         else {
-            $code .= sprintf '%s->{%s} = %s->{%s}; ',
-                $selfvar, $self->_q_name, $argvar, $self->_q_init_arg;
+            $code .= sprintf '%s->{%s} = %s; ',
+                $selfvar, $self->_q_name, $valuevar;
         }
-        $code .= ' }';
+        
+        $code .= $postamble;
+        push @code, $code;
     }
-
-    if ( $self->has_default || $self->has_builder
-    and not $self->lazy ) {
-        if ( $code ) {
-            $code .= ' else { ';
-        }
-        else {
-            $code .= 'do { ';
-        }
-        $code .= sprintf 'my $value = %s; ',
-            $self->_compile_checked_default( $selfvar );
-        $code .= sprintf '%s->{%s} = %s; ',
-            $selfvar, $self->_q_name, '$value';
-        $code .= ' }';
-    }
-    elsif ( defined $init_arg
-    and $self->required
-    and not ($self->has_default || $self->has_builder) ) {
-        $code .= sprintf ' else { %s( "Missing key in constructor: %s" ) }',
-            $self->_function_for_croak, $init_arg;
+    elsif ( $self->has_default || $self->has_builder and not $self->lazy ) {
+        push @code, sprintf '%s->{%s} = %s; ',
+            $selfvar, $self->_q_name, $self->_compile_checked_default( $selfvar );
     }
 
     if ( $self->weak_ref ) {
-      $code .= sprintf ' require Scalar::Util && Scalar::Util::weaken(%s->{%s});',
-         $selfvar, $self->_q_name;
+        push @code, sprintf 'require Scalar::Util && Scalar::Util::weaken(%s->{%s}) if exists %s->{%s};',
+            $selfvar, $self->_q_name, $selfvar, $self->_q_name;
     }
 
-    if ( $self->trigger ) {
-        $code .= ' ' . $self->_compile_trigger(
-            $selfvar,
-            sprintf( '%s->{%s}', $selfvar, $self->_q_name ),
-        ) . ';';
+    for ( @code ) {
+        $_ = "$_;" unless /;\s*$/;
     }
 
-    $code = "$code;" if $code !~ /;$/;
-
-    return $code;
+    return @code;
 }
 
 my %code_template;
@@ -567,7 +592,7 @@ sub compile {
         my $method_name = $self->can($property) ? $self->$property : undef;
         next unless defined $method_name;
 
-        $method_name{$property} = $method_name;
+        $method_name{$property} = $self->_expand_name( $method_name );
         if ( $xs_option_name{$property} ) {
             $want_xs{$property} = 1;
         }
@@ -620,7 +645,7 @@ sub compile {
 
     if ( my $alias_is_for = $self->alias_is_for ) {
         $code .= sprintf "# Aliases for for %s\n", $self->name;
-        my $alias_target = $self->$alias_is_for;
+        my $alias_target = $self->_expand_name( $self->$alias_is_for );
         for my $alias ( $self->_all_aliases ) {
             $code .= sprintf 'sub %s { shift->%s( @_ ) }' . "\n",
                 $alias, $alias_target;
@@ -634,7 +659,7 @@ sub compile {
         my %delegated = %{ $self->handles };
         for my $key ( sort keys %delegated ) {
             $code .= sprintf 'sub %s { shift->%s->%s( @_ ) }' . "\n",
-                $key, $assertion, $delegated{$key};
+                $self->_expand_name( $key ), $assertion, $delegated{$key};
         }
         $code .= "\n";
     }
