@@ -7,7 +7,7 @@ use Mite::Miteception -all;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005003';
+our $VERSION   = '0.005004';
 
 use Path::Tiny;
 use mro;
@@ -234,7 +234,6 @@ sub new {
     my $args  = %s;
     my $no_build = delete $args->{__no_BUILD__};
 
-    # Initialize attributes
     %s
 
     # Enforce strict constructor
@@ -375,11 +374,17 @@ sub _compile_init_attributes {
         values %{ $self->all_attributes };
     };
     for my $attr ( @attributes ) {
-        my $code = $attr->compile_init( $selfvar, $argvar );
-        push @code, $code if $code;
+        $attr->compiling_class( $self );
+        my @lines = grep !!$_, $attr->compile_init( $selfvar, $argvar );
+        if ( @lines ) {
+            push @code, sprintf "# Attribute: %s", $attr->name;
+            push @code, @lines;
+            push @code, '';
+        }
+        $attr->clear_compiling_class;
     }
 
-    return join "\n    ", @code;
+    return join "\n", map { /\S/ ? "    $_" : '' } @code;
 }
 
 sub _compile_attribute_accessors {
@@ -390,7 +395,9 @@ sub _compile_attribute_accessors {
 
     my $code = 'my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };' . "\n\n";
     for my $name ( sort keys %$attributes ) {
+        $attributes->{$name}->compiling_class( $self );
         $code .= $attributes->{$name}->compile( xs_condition => '$__XS' );
+        $attributes->{$name}->clear_compiling_class;
     }
 
     return $code;
