@@ -6,7 +6,7 @@ package Mite::Role;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.005003';
+our $VERSION   = '0.005004';
 
 use Path::Tiny;
 use B ();
@@ -273,7 +273,7 @@ for my $function ( qw/ carp croak confess / ) {
             if $self->imported_functions->{$function};
         return sprintf '%s::%s', $self->shim_name, $function
             if $self->shim_name;
-        return "require Carp && Carp::$function";
+        $function eq 'carp' ? 'warn sprintf' : 'die sprintf';
     };
 }
 
